==> charcoal-0.1.0-alpha.zip: charcoal-0.1.0-alpha/charcoal/core/exception_list.php <==
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
<HEAD>
<META http-equiv='Content-Type' content='text/html; charset=EUC-JP'>
<LINK rel='stylesheet' href='css/error.css' type='text/css'>
</HEAD>
<BODY>

<!-- 㳰ꥹ -->
<TABLE class="error_detail">
<TR>
	  <TH class="error_detail">٥</TH>
	  <TH class="error_detail">㳰</TH>
	  <TH class="error_detail">å</TH>
	  <TH class="error_detail"></TH>
	  <TH class="error_detail">ֹ</TH>
</TR>

<?
$level = 0;
foreach( $cause_list as $cause )
{
	$class_name = get_class($cause);
	$message 	= $cause->getMessage();
	$file 		= basename($cause->getFile());
	$line 		= $cause->getLine();

	print '<TR>';
	print '   <TD class="error_detail">' . $level . '</TD>';
	print '   <TD class="error_detail">' . $class_name . '</TD>';
	print '   <TD class="error_detail">' . $message . '</TD>';
	print '   <TD class="error_detail">' . $file . '</TD>';
	print '   <TD class="error_detail">' . $line . '</TD>';
	print '</TR>';

	$level ++;
}
?>

</TABLE>

<P>

<?
foreach( $cause_list as $cause ){

	if ( $cause instanceof charcoal_Exception ){

		$backtraces = $cause->getBackTrace();
?>
		<!-- Хåȥ졼 -->
		<TABLE class="error_detail">
		<TR>
			  <TH class="error_detail">ؿ̾</TH>
			  <TH class="error_detail">ե̾(ֹ)</TH>
			  <TH class="error_detail"></TH>
		</TR>
<?
		$level = 0;
		foreach( $backtraces as $trace ){
			$func 	= $trace[ 'class' ] . '::' . $trace[ 'function' ];
			$line 	= $trace[ 'line' ];
			$dir	= dirname($trace[ 'file' ]);
			$file 	= basename($trace[ 'file' ]);
			$args	= $trace[ 'args' ];

			print '<TR>';
			print '   <TD class="error_detail">' . $func . '</TD>';
			print '   <TD class="error_detail">' . $dir . '<BR>' . $file . '(' . $line . ')</TD>';
			print '   <TD class="error_detail">' . charcoal_System::arrayToString($args) . '</TD>';
			print '</TR>';

			$level ++;
		}
?>
		</TABLE>
<?
		break;
	}
}
?>

</BODY>
</HTML>

==> charcoal-0.3.0-alpha.zip: charcoal-0.3.0-alpha/charcoal/core/exception_list.php <==
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
<HEAD>
<META http-equiv='Content-Type' content='text/html; charset=EUC-JP'>

<style type="text/css">

/* 顼 */
table.error_digest {
  width: 400px;
  border-width: 2px;
  border-style: solid;
  border-color: #666666; 
  border-collapse: collapse;
}

th.error_digest {
  background-color: gray;
  color: white;
  font-size: 9pt;
  border: 1px #666666 solid;
}

td.error_digest {
  background-color: white;
  color: darkblue;
  font-size: 9pt;
  border: 1px #666666 solid;
}

/* 顼ܺ */
table.error_detail {
  border-width: 2px;
  border-style: solid;
  border-color: #666666; 
  border-collapse: collapse;
}

th.error_detail {
  background-color: gray;
  color: white;
  font-size: 9pt;
  border: 1px #666666 solid;
  padding: 2px;
}

td.error_detail {
  background-color: white;
  color: darkblue;
  font-size: 9pt;
  border: 1px #666666 solid;
  padding: 2px;
}
</style>

</HEAD>
<BODY>

<!-- 㳰ꥹ -->
<TABLE class="error_detail">
<TR>
	  <TH class="error_detail">٥</TH>
	  <TH class="error_detail">㳰</TH>
	  <TH class="error_detail">å</TH>
	  <TH class="error_detail"></TH>
	  <TH class="error_detail">ֹ</TH>
</TR>

<?
$level = 0;
foreach( $cause_list as $cause )
{
	$class_name = get_class($cause);
	$message 	= $cause->getMessage();
	$file 		= basename($cause->getFile());
	$line 		= $cause->getLine();

	print '<TR>';
	print '   <TD class="error_detail">' . $level . '</TD>';
	print '   <TD class="error_detail">' . $class_name . '</TD>';
	print '   <TD class="error_detail">' . $message . '</TD>';
	print '   <TD class="error_detail">' . $file . '</TD>';
	print '   <TD class="error_detail">' . $line . '</TD>';
	print '</TR>';

	$level ++;
}
?>

</TABLE>

<P>

<?
foreach( $cause_list as $cause ){

	if ( $cause instanceof charcoal_Exception ){

		$backtraces = $cause->getBackTrace();
?>
		<!-- Хåȥ졼 -->
		<TABLE class="error_detail">
		<TR>
			  <TH class="error_detail">ؿ̾</TH>
			  <TH class="error_detail">ե̾(ֹ)</TH>
			  <TH class="error_detail"></TH>
		</TR>
<?
		$level = 0;
		foreach( $backtraces as $trace ){
			$func 	= $trace[ 'class' ] . '::' . $trace[ 'function' ];
			$line 	= $trace[ 'line' ];
			$dir	= dirname($trace[ 'file' ]);
			$file 	= basename($trace[ 'file' ]);
			$args	= $trace[ 'args' ];

			print '<TR>';
			print '   <TD class="error_detail">' . $func . '</TD>';
			print '   <TD class="error_detail">' . $dir . '<BR>' . $file . '(' . $line . ')</TD>';
			print '   <TD class="error_detail">' . charcoal_System::arrayToString($args) . '</TD>';
			print '</TR>';

			$level ++;
		}
?>
		</TABLE>
<?
		break;
	}
}
?>

</BODY>
</HTML>
